# pythonHelpers
This package contains common utility functions written in python.

[![GitHub License](https://img.shields.io/github/license/impratikjaiswal/pythonHelpers)](LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)

[![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/pythonHelpers)](https://github.com/impratikjaiswal/pythonHelpers/releases/latest)
[![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/pythonHelpers/latest)](https://github.com/impratikjaiswal/pythonHelpers/commits/main/)

[![Static Badge](https://img.shields.io/badge/amenitypj.in/-a?label=website%20url)](https://amenitypj.in)
[![Website](https://img.shields.io/website?url=https://amenitypj.in&label=website%20status)](https://amenitypj.in)

[![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/pythonHelpers-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/pythonHelpers)
[![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/pythonHelpers&label=website%20status)](https://impratikjaiswal.github.io/pythonHelpers)

# Url(s) of AmenityPj 
Refer [Url(s) of AmenityPj](https://impratikjaiswal.github.io/amenitypj/#urls-of-amenitypj) for details.

# Screen Shot(s) of Web App [![Static Badge](https://img.shields.io/badge/amenitypj.in-a)](https://amenitypj.in/) 
![sample_web_1](https://github.com/impratikjaiswal/amenitypj/blob/main/static/images/sample_web_1.gif?raw=true)

# Installation/Setup
Steps can be found [here](https://github.com/impratikjaiswal/pythonHelpers/blob/main/HOW_TO_INSTALL_PYTHON_APPS.md).

# How To Use
There are various ways to Get Started:

  - Online Mode
    - Website [![Static Badge](https://img.shields.io/badge/amenitypj.in-a)](https://amenitypj.in/) can be used
  - Offline Mode (Requires Download / Cloning of the Repo)
    - Code (as a library) can be directly imported from ```pythonHelpers/ph_*.py``` using any IDE

# Help
Issue tracker can be found [here](CONTRIBUTING.md#issue-tracker).

# Contributing
 - Code of Conduct can be found [here](CODE_OF_CONDUCT.md).
 - Contributing Guidelines can be found [here](CONTRIBUTING.md).
